@@ -52,13 +52,13 @@ PLAN_RESULT_SCHEMA = '''{
                                 "type": "integer"
                             },
                             "latitude": {
-                                "format": "float",
+                                "format": "double",
                                 "maximum": 90,
                                 "minimum": -90,
                                 "type": "number"
                             },
                             "longitude": {
-                                "format": "float",
+                                "format": "double",
                                 "maximum": 180,
                                 "minimum": -180,
                                 "type": "number"
